@@ -41,7 +41,7 @@
 /*  Alternative random number generator  */
 
 #define AltRandom my_rand()
-static double my_rand() {
+static double my_rand(void) {
   double dval;
   GetRNGstate();
   dval = runif(0, 1);
